@@ -1,30 +1,32 @@
 #' Opens SQLite Database Connection
 #'
-#' Opens a \code{\linkS4class{SQLiteConnection}} to a SQLite database with
+#' Opens a [SQLiteConnection-class] to a SQLite database with
 #' foreign key constraints enabled.
 #'
 #' @inheritParams RSQLite::SQLite
 #' @param exists A flag specifying whether the table(s) must already exist.
-#' @return A \code{\linkS4class{SQLiteConnection}} to a SQLite database with
+#' @return A [SQLiteConnection-class] to a SQLite database with
 #' foreign key constraints enabled.
 #' @aliases rws_open_connection
-#' @seealso \code{\link{rws_disconnect}()}
+#' @seealso [rws_disconnect()]
 #' @export
-#' 
-#' @examples 
+#'
+#' @examples
 #' conn <- rws_connect()
 #' print(conn)
 #' rws_disconnect(conn)
 rws_connect <- function(dbname = ":memory:", exists = NA) {
-  check_string(dbname)
-  check_scalar(exists, c(TRUE, NA))
-  
-  if(isTRUE(exists) && !file.exists(dbname))
-    err("File '", dbname,"' must already exist.")
+  chk_string(dbname)
+  chk_lgl(exists)
+
+  if (vld_true(exists) && !file.exists(dbname)) {
+    err("File '", dbname, "' must already exist.")
+  }
+
+  if (vld_false(exists) && file.exists(dbname)) {
+    err("File '", dbname, "' must not already exist.")
+  }
 
-  if(isFALSE(exists) && file.exists(dbname))
-    err("File '", dbname,"' must not already exist.")
-  
   conn <- DBI::dbConnect(RSQLite::SQLite(), dbname = dbname)
   execute("PRAGMA foreign_keys = ON;", conn)
   conn
@@ -32,18 +34,18 @@ rws_connect <- function(dbname = ":memory:", exists = NA) {
 
 #' Close SQLite Database Connection
 #'
-#' Closes a \code{\linkS4class{SQLiteConnection}} to a SQLite database.
+#' Closes a [SQLiteConnection-class] to a SQLite database.
 #'
 #' @inheritParams RSQLite::SQLite
 #' @aliases rws_close_connection
-#' @seealso \code{\link{rws_connect}()}
+#' @seealso [rws_connect()]
 #' @export
-#' 
-#' @examples 
+#'
+#' @examples
 #' conn <- rws_connect()
 #' rws_disconnect(conn)
 #' print(conn)
 rws_disconnect <- function(conn) {
-  check_sqlite_connection(conn)
+  chk_sqlite_conn(conn)
   DBI::dbDisconnect(conn)
 }
